@@ -26,14 +26,11 @@ from enum import unique
 from pathlib import Path
 from typing import Union
 
-import geopandas as gpd
-import rasterio
 from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio import crs as riocrs
-from sertit import files, rasters, rasters_rio, vectors
+from sertit import files, vectors
 from sertit.misc import ListEnum
-from sertit.rasters import XDS_TYPE
 
 from eoreader import cache, cached_property
 from eoreader.bands import BandNames
@@ -232,28 +229,13 @@ class MaxarProduct(VhrProduct):
     for more information.
     """
 
-    def __init__(
-        self,
-        product_path: Union[str, CloudPath, Path],
-        archive_path: Union[str, CloudPath, Path] = None,
-        output_path: Union[str, CloudPath, Path] = None,
-        remove_tmp: bool = False,
-    ) -> None:
-        self.ortho_path = None
-        """
-        Orthorectified path.
-        Can be set to use manually orthorectified or pansharpened data, especially useful for VHR data on steep terrain.
-        """
-
-        # Initialization from the super class
-        super().__init__(product_path, archive_path, output_path, remove_tmp)
-
     def _pre_init(self) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
         """
         self.needs_extraction = False
+        self._proj_prod_type = [MaxarProductType.Standard]
 
         # Post init done by the super class
         super()._pre_init()
@@ -358,6 +340,12 @@ class MaxarProduct(VhrProduct):
                         obn.RED: 2,
                         obn.GREEN: 3,
                         obn.BLUE: 4,
+                        obn.WV: 5,
+                        obn.VRE_1: 6,
+                        obn.VRE_2: 6,
+                        obn.VRE_3: 6,
+                        obn.YELLOW: 7,
+                        obn.CA: 8,
                     }
                 )
             else:
@@ -368,10 +356,6 @@ class MaxarProduct(VhrProduct):
                         obn.RED: 2,
                         obn.GREEN: 3,
                         obn.BLUE: 4,
-                        obn.WV: 5,
-                        obn.RE: 6,
-                        obn.YELLOW: 7,
-                        obn.CA: 8,
                     }
                 )
         else:
@@ -448,31 +432,9 @@ class MaxarProduct(VhrProduct):
 
         return utm
 
-    @cached_property
-    def footprint(self) -> gpd.GeoDataFrame:
-        """
-        Get real footprint in UTM of the products (without nodata, in french == emprise utile)
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.footprint
-                                                         gml_id  ...                                           geometry
-            0  source_image_footprint-DS_PHR1A_20200511023124...  ...  POLYGON ((707025.261 9688613.833, 707043.276 9...
-            [1 rows x 3 columns]
-
-        Returns:
-            gpd.GeoDataFrame: Footprint as a GeoDataFrame
-        """
-        # Get footprint
-        # TODO: Optimize that
-        return rasters.get_footprint(self.get_default_band_path()).to_crs(self.crs)
-
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format  :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -495,9 +457,11 @@ class MaxarProduct(VhrProduct):
             root, _ = self.read_mtd()
             datetime_str = root.findtext(".//EARLIESTACQTIME")
             if not datetime_str:
-                raise InvalidProductError(
-                    "Cannot find EARLIESTACQTIME in the metadata file."
-                )
+                datetime_str = root.findtext(".//FIRSTLINETIME")
+                if not datetime_str:
+                    raise InvalidProductError(
+                        "Cannot find EARLIESTACQTIME or FIRSTLINETIME in the metadata file."
+                    )
 
             # Convert to datetime
             datetime_str = datetime.strptime(datetime_str, "%Y-%m-%dT%H:%M:%S.%fZ")
@@ -519,68 +483,7 @@ class MaxarProduct(VhrProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        return files.get_filename(self._get_til_path())
-
-    def _get_ortho_path(self) -> Union[CloudPath, Path]:
-        """
-        Get the orthorectified path of the bands.
-
-        Returns:
-            Union[CloudPath, Path]: Orthorectified path
-        """
-
-        if self.product_type == MaxarProductType.Standard:
-            ortho_name = f"{self.condensed_name}_ortho.tif"
-            ortho_path = self._get_band_folder().joinpath(ortho_name)
-            if not ortho_path.is_file():
-                ortho_path = self._get_band_folder(writable=True).joinpath(ortho_name)
-                LOGGER.info(
-                    f"Manually orthorectified stack not given by the user. "
-                    f"Reprojecting data here: {ortho_path} "
-                    "(May be inaccurate on steep terrain, depending on the DEM resolution.)"
-                )
-
-                # Reproject and write on disk data
-                with rasterio.open(str(self._get_til_path())) as src:
-                    out_arr, meta = self._reproject(src.read(), src.meta, src.rpcs)
-                    rasters_rio.write(out_arr, meta, ortho_path)
-
-        else:
-            ortho_path = self._get_til_path()
-
-        return ortho_path
-
-    # pylint: disable=R0913
-    # R0913: Too many arguments (6/5) (too-many-arguments)
-    def _manage_invalid_pixels(
-        self, band_arr: XDS_TYPE, band: obn, **kwargs
-    ) -> XDS_TYPE:
-        """
-        Manage invalid pixels (Nodata, saturated, defective...)
-        See
-        `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`_
-        (unusable data mask) for more information.
-
-        Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
-            kwargs: Other arguments used to load bands
-
-        Returns:
-            XDS_TYPE: Cleaned band array
-        """
-        # Do nothing
-
-        return band_arr
-
-    def _get_condensed_name(self) -> str:
-        """
-        Get PlanetScope products condensed name ({date}_PLD_{product_type}_{band_combi}).
-
-        Returns:
-            str: Condensed name
-        """
-        return f"{self.get_datetime()}_{self.platform.name}_{self.product_type.name}_{self.band_combi.name}"
+        return files.get_filename(self._get_tile_path())
 
     @cache
     def get_mean_sun_angles(self) -> (float, float):
@@ -622,7 +525,7 @@ class MaxarProduct(VhrProduct):
             (etree._Element, dict): Metadata XML root and its namespaces as a dict
         """
         mtd_from_path = ".XML"
-        mtd_archived = "\.XML"
+        mtd_archived = r"\.XML"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
@@ -655,7 +558,7 @@ class MaxarProduct(VhrProduct):
 
         return {}
 
-    def _get_til_path(self) -> Union[CloudPath, Path]:
+    def _get_tile_path(self) -> Union[CloudPath, Path]:
         """
         Get the DIMAP filepath
 
