@@ -50,7 +50,7 @@ LOGGER = logging.getLogger(EOREADER_NAME)
 @unique
 class PlaInstrument(ListEnum):
     """PlanetScope instrument
-    See `here <https://developers.planet.com/docs/apis/data/sensors/>`_
+    See `here <https://developers.planet.com/docs/apis/data/sensors/>`__
     for more information.
     """
 
@@ -178,7 +178,7 @@ class PlaProductType(ListEnum):
 class PlaProduct(OpticalProduct):
     """
     Class of PlanetScope products.
-    See `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`_
+    See `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`__
     for more information.
 
     The scaling factor to retrieve the calibrated radiance is 0.01.
@@ -318,7 +318,7 @@ class PlaProduct(OpticalProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -367,19 +367,15 @@ class PlaProduct(OpticalProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
-            # Get MTD XML file
-            root, nsmap = self.read_mtd()
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
 
-            # Open identifier
-            try:
-                name = root.findtext(f".//{nsmap['eop']}identifier")
-            except TypeError:
-                raise InvalidProductError(
-                    f"{nsmap['eop']}identifier not found in metadata!"
-                )
-        else:
-            name = self.name
+        # Open identifier
+        name = root.findtext(f".//{nsmap['eop']}identifier")
+        if not name:
+            raise InvalidProductError(
+                f"{nsmap['eop']}identifier not found in metadata!"
+            )
 
         return name
 
@@ -464,8 +460,6 @@ class PlaProduct(OpticalProduct):
 
         return band_xda
 
-    # pylint: disable=R0913
-    # R0913: Too many arguments (6/5) (too-many-arguments)
     def _manage_invalid_pixels(
         self, band_arr: XDS_TYPE, band: obn, **kwargs
     ) -> XDS_TYPE:
@@ -494,7 +488,7 @@ class PlaProduct(OpticalProduct):
         }
         udm = self.open_mask("UNUSABLE", size=(band_arr.rio.width, band_arr.rio.height))
         # Workaround:
-        # FutureWarning: The `numpy.expand_dims` function is not implemented by Dask array.
+        # FutureWarning: The :code:`numpy.expand_dims` function is not implemented by Dask array.
         # You may want to use the da.map_blocks function or something similar to silence this warning.
         # Your code may stop working in a future release.
         dubious_mask = rasters.read_bit_array(udm.values, dubious_bands[band])
@@ -505,6 +499,26 @@ class PlaProduct(OpticalProduct):
         # -- Merge masks
         return self._set_nodata_mask(band_arr, mask)
 
+    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
+        """
+        Manage only nodata pixels
+
+        Args:
+            band_arr (XDS_TYPE): Band array
+            band (obn): Band name as an OpticalBandNames
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            XDS_TYPE: Cleaned band array
+        """
+        # Nodata
+        no_data_mask = self._load_nodata(
+            size=(band_arr.rio.width, band_arr.rio.height)
+        ).values
+
+        # -- Merge masks
+        return self._set_nodata_mask(band_arr, no_data_mask)
+
     def _load_bands(
         self,
         bands: list,
@@ -528,7 +542,7 @@ class PlaProduct(OpticalProduct):
             return {}
 
         # Get band paths
-        band_paths = self.get_band_paths(bands)
+        band_paths = self.get_band_paths(bands, **kwargs)
 
         # Open bands and get array (resampled if needed)
         band_arrays = self._open_bands(
@@ -605,7 +619,7 @@ class PlaProduct(OpticalProduct):
             (etree._Element, dict): Metadata XML root and its namespaces as a dict
         """
         mtd_from_path = "metadata*.xml"
-        mtd_archived = "metadata.*\.xml"
+        mtd_archived = r"metadata.*\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
@@ -694,8 +708,11 @@ class PlaProduct(OpticalProduct):
 
                 # Rename
                 band_name = to_str(band)[0]
-                cloud.attrs["long_name"] = band_name
-                band_dict[band] = cloud.rename(band_name)
+
+                # Multi bands -> do not change long name
+                if band != RAW_CLOUDS:
+                    cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
 
@@ -709,21 +726,21 @@ class PlaProduct(OpticalProduct):
         Open a Planet UDM2 (Usable Data Mask) mask, band by band, as a xarray.
         Returns None if the mask is not available.
 
-        Do not open cloud mask with this function. Use `load` instead.
+        Do not open cloud mask with this function. Use :code:`load` instead.
 
         See `here <https://developers.planet.com/docs/data/udm-2/>`_ for more
         information.
 
         Accepted mask IDs:
 
-        - `CLEAR`:      Band 1     Clear map        [0, 1]  0: not clear, 1: clear
-        - `SNOW`:       Band 2     Snow map         [0, 1]  0: no snow or ice, 1: snow or ice
-        - `SHADOW`:     Band 3     Shadow map       [0, 1]  0: no shadow, 1: shadow
-        - `LIGHT_HAZE`: Band 4     Light haze map   [0, 1]  0: no light haze, 1: light haze
-        - `HEAVY_HAZE`: Band 5     Heavy haze map   [0, 1]  0: no heavy haze, 1: heavy haze
-        - `CLOUD`:      Band 6     Cloud map        [0, 1]  0: no cloud, 1: cloud
-        - `CONFIDENCE`: Band 7     Confidence map   [0-100] %age value: per-pixel algorithmic confidence in classif
-        - `UNUSABLE`:   Band 8     Unusable pixels  --      Equivalent to the UDM asset
+        - :code:`CLEAR`:      Band 1     Clear map        [0, 1]  0: not clear, 1: clear
+        - :code:`SNOW`:       Band 2     Snow map         [0, 1]  0: no snow or ice, 1: snow or ice
+        - :code:`SHADOW`:     Band 3     Shadow map       [0, 1]  0: no shadow, 1: shadow
+        - :code:`LIGHT_HAZE`: Band 4     Light haze map   [0, 1]  0: no light haze, 1: light haze
+        - :code:`HEAVY_HAZE`: Band 5     Heavy haze map   [0, 1]  0: no heavy haze, 1: heavy haze
+        - :code:`CLOUD`:      Band 6     Cloud map        [0, 1]  0: no cloud, 1: cloud
+        - :code:`CONFIDENCE`: Band 7     Confidence map   [0-100] %age value: per-pixel algorithmic confidence in classif
+        - :code:`UNUSABLE`:   Band 8     Unusable pixels  --      Equivalent to the UDM asset
 
         .. code-block:: python
 
@@ -809,9 +826,9 @@ class PlaProduct(OpticalProduct):
         try:
             if self.is_archived:
                 if invalid_lookahead:
-                    regex = f".*{filename}(?!{invalid_lookahead})\w*[_]*\.{extension}"
+                    regex = rf".*{filename}(?!{invalid_lookahead})\w*[_]*\.{extension}"
                 else:
-                    regex = f".*{filename}\w*[_]*\.{extension}"
+                    regex = rf".*{filename}\w*[_]*\.{extension}"
 
                 path = files.get_archived_rio_path(self.path, regex)
             else:
