@@ -52,11 +52,11 @@ LOGGER = logging.getLogger(EOREADER_NAME)
 class S2ProductType(ListEnum):
     """Sentinel-2 products types (L1C or L2A)"""
 
-    L1C = "Level-1C"
-    """L1C: https://sentinel.esa.int/web/sentinel/user-guides/sentinel-2-msi/product-types/level-1c"""
+    L1C = "MSIL1C"
+    """Level-1C: https://sentinel.esa.int/web/sentinel/user-guides/sentinel-2-msi/product-types/level-1c"""
 
-    L2A = "Level-2A"
-    """L2A: https://sentinel.esa.int/web/sentinel/user-guides/sentinel-2-msi/product-types/level-2a"""
+    L2A = "MSIL2A"
+    """Level-2A: https://sentinel.esa.int/web/sentinel/user-guides/sentinel-2-msi/product-types/level-2a"""
 
 
 @unique
@@ -150,12 +150,8 @@ class S2Product(OpticalProduct):
         """
         self.tile_name = self._get_tile_name()
 
-        # Get processing baseline
-        root, _ = self.read_datatake_mtd()
-        try:
-            pr_baseline = float(root.findtext(".//PROCESSING_BASELINE"))
-        except TypeError:
-            raise InvalidProductError("PRODUCT_URI not found in datatake metadata!")
+        # Get processing baseline: N0213 -> 02.13
+        pr_baseline = float(self.split_name[3][1:]) / 100
         self._processing_baseline_lt_4_0 = pr_baseline < 4.0
 
         # Post init done by the super class
@@ -165,9 +161,9 @@ class S2Product(OpticalProduct):
         """
         Set product default resolution (in meters)
         """
-        # S2: use 20m resolution, even if we have 60m and 10m resolution
+        # S2: use 10m resolution, even if we have 60m and 20m resolution
         # In the future maybe set one resolution per band ?
-        return 20.0
+        return 10.0
 
     def _get_tile_name(self) -> str:
         """
@@ -180,19 +176,11 @@ class S2Product(OpticalProduct):
 
     def _set_product_type(self) -> None:
         """Set products type"""
-        # Get MTD XML file
-        root, _ = self.read_datatake_mtd()
 
         # Open identifier
-        try:
-            product_lvl = root.findtext(".//PROCESSING_LEVEL")
-        except TypeError:
-            raise InvalidProductError(
-                "PROCESSING_LEVEL not found in datatake metadata!"
-            )
+        self.product_type = S2ProductType.from_value(self.split_name[1])
 
-        if product_lvl == S2ProductType.L2A.value:
-            self.product_type = S2ProductType.L2A
+        if self.product_type == S2ProductType.L2A:
             self.band_names.map_bands(
                 {
                     obn.CA: "01",
@@ -209,8 +197,7 @@ class S2Product(OpticalProduct):
                     obn.SWIR_2: "12",
                 }
             )
-        elif product_lvl == S2ProductType.L1C.value:
-            self.product_type = S2ProductType.L1C
+        elif self.product_type == S2ProductType.L1C:
             self.band_names.map_bands(
                 {
                     obn.CA: "01",
@@ -268,7 +255,7 @@ class S2Product(OpticalProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. WARNING::
             Sentinel-2 datetime is the datatake sensing time, not the granule sensing time !
@@ -291,20 +278,11 @@ class S2Product(OpticalProduct):
              Union[str, datetime.datetime]: Its acquisition datetime
         """
         if self.datetime is None:
-            # Get MTD XML file
-            root, _ = self.read_datatake_mtd()
-
-            # Open identifier
-            try:
-                # Sentinel-2 datetime (in the filename) is the datatake sensing time, not the granule sensing time !
-                sensing_time = root.findtext(".//PRODUCT_START_TIME")
-            except TypeError:
-                raise InvalidProductError(
-                    "PRODUCT_START_TIME not found in datatake metadata!"
-                )
+            # Sentinel-2 datetime (in the filename) is the datatake sensing time, not the granule sensing time !
+            sensing_time = self.split_name[2]
 
             # Convert to datetime
-            date = datetime.strptime(sensing_time, "%Y-%m-%dT%H:%M:%S.%fZ")
+            date = datetime.strptime(sensing_time, "%Y%m%dT%H%M%S")
         else:
             date = self.datetime
 
@@ -320,17 +298,17 @@ class S2Product(OpticalProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
+        try:
             # Get MTD XML file
             root, _ = self.read_datatake_mtd()
 
             # Open identifier
-            try:
-                name = files.get_filename(root.findtext(".//PRODUCT_URI"))
-            except TypeError:
+            name = files.get_filename(root.findtext(".//PRODUCT_URI"))
+            if not name:
                 raise InvalidProductError("PRODUCT_URI not found in metadata!")
-        else:
-            name = self.name
+        except InvalidProductError:
+            tile_info = files.read_json(next(self.path.glob("**/tileInfo.json")))
+            name = tile_info["productName"]
 
         return name
 
@@ -492,39 +470,52 @@ class S2Product(OpticalProduct):
         )
 
         if str(path).endswith(".jp2"):
-            # Get MTD XML file
-            root, _ = self.read_datatake_mtd()
-
-            # Get quantification value
-            quantif_prefix = "BOA_" if self.product_type == S2ProductType.L2A else ""
             try:
-                quantif_value = float(
-                    root.findtext(f".//{quantif_prefix}QUANTIFICATION_VALUE")
-                )
-            except TypeError:
-                raise InvalidProductError(
-                    f"{quantif_prefix}QUANTIFICATION_VALUE not found in datatake metadata!"
-                )
+                # Get MTD XML file
+                root, _ = self.read_datatake_mtd()
 
-            # Get offset
-            offset_prefix = (
-                "BOA_" if self.product_type == S2ProductType.L2A else "RADIO_"
-            )
-            if self._processing_baseline_lt_4_0:
-                offset = 0.0
-            else:
+                # Get quantification value
+                quantif_prefix = (
+                    "BOA_" if self.product_type == S2ProductType.L2A else ""
+                )
                 try:
-                    band_id = str(int(self.band_names[band]))
-                    offset = float(
-                        root.findtext(
-                            f".//{offset_prefix}ADD_OFFSET[@band_id = '{band_id}']"
-                        )
+                    quantif_value = float(
+                        root.findtext(f".//{quantif_prefix}QUANTIFICATION_VALUE")
                     )
                 except TypeError:
                     raise InvalidProductError(
-                        f"{offset_prefix}ADD_OFFSET not found in datatake metadata!"
+                        f"{quantif_prefix}QUANTIFICATION_VALUE not found in datatake metadata!"
                     )
 
+                # Get offset
+                offset_prefix = (
+                    "BOA_" if self.product_type == S2ProductType.L2A else "RADIO_"
+                )
+                if self._processing_baseline_lt_4_0:
+                    offset = 0.0
+                else:
+                    try:
+                        if band == obn.NARROW_NIR:
+                            band_id = 8
+                        else:
+                            band_id = int(self.band_names[band])
+                        offset = float(
+                            root.findtext(
+                                f".//{offset_prefix}ADD_OFFSET[@band_id = '{band_id}']"
+                            )
+                        )
+                    except TypeError:
+                        raise InvalidProductError(
+                            f"{offset_prefix}ADD_OFFSET not found in datatake metadata!"
+                        )
+            except InvalidProductError:
+                # If not datatake file
+                if self._processing_baseline_lt_4_0:
+                    offset = 0.0
+                else:
+                    offset = -1000.0
+                quantif_value = 10000.0
+
             # Compute the correct radiometry of the band
             band_xda = (band_xda - offset) / quantif_value
 
@@ -534,16 +525,16 @@ class S2Product(OpticalProduct):
         self, mask_id: Union[str, S2GmlMasks], band: Union[obn, str] = None
     ) -> gpd.GeoDataFrame:
         """
-        Open S2 mask (GML files stored in QI_DATA) as `gpd.GeoDataFrame`.
+        Open S2 mask (GML files stored in QI_DATA) as :code:`gpd.GeoDataFrame`.
 
         Masks than can be called that way are:
 
-        - `TECQUA`: Technical quality mask
-        - `SATURA`: Saturated Pixels
-        - `NODATA`: Pixel nodata (inside the detectors)
-        - `DETFOO`: Detectors footprint -> used to process nodata outside the detectors
-        - `DEFECT`: Defective pixels
-        - `CLOUDS`, **only with `00` as a band !**
+        - :code:`TECQUA`: Technical quality mask
+        - :code:`SATURA`: Saturated Pixels
+        - :code:`NODATA`: Pixel nodata (inside the detectors)
+        - :code:`DETFOO`: Detectors footprint -> used to process nodata outside the detectors
+        - :code:`DEFECT`: Defective pixels
+        - :code:`CLOUDS`, **only with :code:`00` as a band !**
 
         .. code-block:: python
 
@@ -624,15 +615,16 @@ class S2Product(OpticalProduct):
         band: Union[obn, str] = None,
         resolution: float = None,
         size: Union[list, tuple] = None,
+        **kwargs,
     ) -> xr.DataArray:
         """
         Open S2 mask (jp2 files stored in QI_DATA) as raster.
 
         Masks than can be called that way are:
 
-        - `DETFOO`: Detectors footprint -> used to process nodata outside the detectors
-        - `QUALIT`: TECQUA, DEFECT, NODATA, SATURA, CLOLOW merged
-        - `CLASSI`: CLOUDS and SNOICE **only with `00` as a band !**
+        - :code:`DETFOO`: Detectors footprint -> used to process nodata outside the detectors
+        - :code:`QUALIT`: TECQUA, DEFECT, NODATA, SATURA, CLOLOW merged
+        - :code:`CLASSI`: CLOUDS and SNOICE **only with :code:`00` as a band !**
 
         Args:
             mask_id (Union[str, S2GmlMasks]): Mask ID
@@ -667,7 +659,13 @@ class S2Product(OpticalProduct):
             )
 
         # Read mask
-        mask = rasters.read(mask_path, resolution=resolution, size=size)
+        mask = utils.read(
+            mask_path,
+            resolution=resolution,
+            size=size,
+            resampling=Resampling.nearest,
+            **kwargs,
+        )
 
         return mask
 
@@ -689,10 +687,26 @@ class S2Product(OpticalProduct):
         if self._processing_baseline_lt_4_0:
             return self._manage_invalid_pixels_lt_4_0(band_arr, band, **kwargs)
         else:
+            # return band_arr
             return self._manage_invalid_pixels_gt_4_0(band_arr, band, **kwargs)
 
-    # pylint: disable=R0913
-    # R0913: Too many arguments (6/5) (too-many-arguments)
+    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
+        """
+        Manage only nodata pixels
+
+        Args:
+            band_arr (XDS_TYPE): Band array
+            band (obn): Band name as an OpticalBandNames
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            XDS_TYPE: Cleaned band array
+        """
+        if self._processing_baseline_lt_4_0:
+            return self._manage_nodata_lt_4_0(band_arr, band, **kwargs)
+        else:
+            return self._manage_nodata_gt_4_0(band_arr, band, **kwargs)
+
     def _manage_invalid_pixels_lt_4_0(
         self, band_arr: XDS_TYPE, band: obn, **kwargs
     ) -> XDS_TYPE:
@@ -764,7 +778,8 @@ class S2Product(OpticalProduct):
     ) -> XDS_TYPE:
         """
         Manage invalid pixels (Nodata, saturated, defective...)
-        See there: https://sentinel.esa.int/documents/247904/349490/S2_MSI_Product_Specification.pdf
+        See there:
+        https://sentinels.copernicus.eu/documents/247904/685211/Sentinel-2-Products-Specification-Document-14_8.pdf
 
         Args:
             band_arr (XDS_TYPE): Band array
@@ -786,26 +801,90 @@ class S2Product(OpticalProduct):
         nodata = np.where(band_arr.compute() == 0, self._mask_true, self._mask_false)
 
         # Manage quality mask
+        # TODO: Optimize it -> very slow (why ?)
+        # Technical quality mask: Only keep MSI_LOST (band 3) and MSI_DEG (band 4)
+        # Defective pixels (band 5)
+        # Nodata pixels (band 6)
+        # Saturated pixels (band 8)
         quality = (
             self._open_mask_gt_4_0(
-                S2Jp2Masks.QUALITY, band, size=(band_arr.rio.width, band_arr.rio.height)
+                S2Jp2Masks.QUALITY,
+                band,
+                size=(band_arr.rio.width, band_arr.rio.height),
+                indexes=[3, 4, 5, 6, 8],
+                masked=False,
             )
-            .compute()
             .astype(np.uint8)
+            .data
         )
 
-        # Technical quality mask: Only keep MSI_LOST (band 3) and MSI_DEG (band 4)
-        # Defectuous pixels (band 5)
-        # Saturated pixels (band 8)
-        bands_id = [3, 4, 5, 7]  # Band - 1
-        qual_mask = np.bitwise_or.reduce(
-            [quality[band_id, :, :] for band_id in bands_id]
-        )
-
-        mask = nodata | qual_mask
+        # Compute mask
+        mask = (nodata + np.sum(quality, axis=0)) > 0
 
         return self._set_nodata_mask(band_arr, mask)
 
+    def _manage_nodata_lt_4_0(
+        self, band_arr: XDS_TYPE, band: obn, **kwargs
+    ) -> XDS_TYPE:
+        """
+        Manage only nodata
+        See there: https://sentinel.esa.int/documents/247904/349490/S2_MSI_Product_Specification.pdf
+
+        Args:
+            band_arr (XDS_TYPE): Band array
+            band (obn): Band name as an OpticalBandNames
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            XDS_TYPE: Cleaned band array
+        """
+        # Get detector footprint to deduce the outside nodata
+        nodata_det = self._open_mask_lt_4_0(
+            S2GmlMasks.FOOTPRINT, band
+        )  # Detector nodata, -> pixels that are outside of the detectors
+
+        # Rasterize nodata
+        mask = features.rasterize(
+            nodata_det.geometry,
+            out_shape=(band_arr.rio.height, band_arr.rio.width),
+            fill=self._mask_true,  # Outside detector = nodata (inverted compared to the usual)
+            default_value=self._mask_false,  # Inside detector = not nodata
+            transform=transform.from_bounds(
+                *band_arr.rio.bounds(), band_arr.rio.width, band_arr.rio.height
+            ),
+            dtype=np.uint8,
+        )
+
+        return self._set_nodata_mask(band_arr, mask)
+
+    def _manage_nodata_gt_4_0(
+        self, band_arr: XDS_TYPE, band: obn, **kwargs
+    ) -> XDS_TYPE:
+        """
+        Manage only nodata
+        See there: https://sentinel.esa.int/documents/247904/349490/S2_MSI_Product_Specification.pdf
+
+        Args:
+            band_arr (XDS_TYPE): Band array
+            band (obn): Band name as an OpticalBandNames
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            XDS_TYPE: Cleaned band array
+        """
+        # Get detector footprint to deduce the outside nodata
+        # TODO: use them ?
+        # nodata = self._open_mask_gt_4_0(
+        #     S2Jp2Masks.FOOTPRINT, band, size=(band_arr.rio.width, band_arr.rio.height)
+        # ).data.astype(
+        #     np.uint8
+        # )  # Detector nodata, -> pixels that are outside of the detectors
+
+        # Set to nodata where the array is set to 0
+        nodata = np.where(band_arr.compute() == 0, self._mask_true, self._mask_false)
+
+        return self._set_nodata_mask(band_arr, nodata)
+
     def _load_bands(
         self,
         bands: list,
@@ -830,7 +909,7 @@ class S2Product(OpticalProduct):
 
         if resolution is None and size is not None:
             resolution = self._resolution_from_size(size)
-        band_paths = self.get_band_paths(bands, resolution=resolution)
+        band_paths = self.get_band_paths(bands, resolution=resolution, **kwargs)
 
         # Open bands and get array (resampled if needed)
         band_arrays = self._open_bands(
@@ -847,18 +926,8 @@ class S2Product(OpticalProduct):
             str: Condensed name
         """
         # Used to make the difference between 2 products acquired on the same tile at the same date but cut differently
-        # Get MTD XML file
-        root, _ = self.read_datatake_mtd()
-
-        # Open identifier
-        try:
-            gen_time = root.findtext(".//GENERATION_TIME")
-        except TypeError:
-            raise InvalidProductError("GENERATION_TIME not found in datatake metadata!")
-
-        gen_time = datetime.strptime(gen_time, "%Y-%m-%dT%H:%M:%S.%fZ").strftime(
-            "%H%M%S"
-        )
+        # Sentinel-2 generation time: "%Y%m%dT%H%M%S" -> save only %H%M%S
+        gen_time = self.split_name[-1].split("T")[-1]
         return f"{self.get_datetime()}_{self.platform.name}_{self.tile_name}_{self.product_type.name}_{gen_time}"
 
     @cache
@@ -907,7 +976,7 @@ class S2Product(OpticalProduct):
             (etree._Element, dict): Metadata XML root and its namespaces
         """
         mtd_from_path = "GRANULE/*/*.xml"
-        mtd_archived = "GRANULE.*\.xml"
+        mtd_archived = r"GRANULE.*\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
@@ -915,7 +984,7 @@ class S2Product(OpticalProduct):
     def read_datatake_mtd(self) -> (etree._Element, dict):
         """
         Read datatake metadata and outputs the metadata XML root and its namespaces as a dict
-        (datatake metadata is the file in the root directory named `MTD_MSI(L1C/L2A).xml`)
+        (datatake metadata is the file in the root directory named :code:`MTD_MSI(L1C/L2A).xml`)
 
         .. code-block:: python
 
@@ -930,7 +999,7 @@ class S2Product(OpticalProduct):
             (etree._Element, dict): Metadata XML root and its namespaces
         """
         mtd_from_path = "MTD_MSI*.xml"
-        mtd_archived = "MTD_MSI.*\.xml"
+        mtd_archived = r"MTD_MSI.*\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
@@ -1006,8 +1075,11 @@ class S2Product(OpticalProduct):
 
                 # Rename
                 band_name = to_str(band)[0]
-                cloud.attrs["long_name"] = band_name
-                band_dict[band] = cloud.rename(band_name)
+
+                # Multi bands -> do not change long name
+                if band != RAW_CLOUDS:
+                    cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
 
@@ -1058,8 +1130,12 @@ class S2Product(OpticalProduct):
 
                 # Rename
                 band_name = to_str(band)[0]
-                cloud.attrs["long_name"] = band_name
-                band_dict[band] = cloud.rename(band_name)
+
+                # Multi bands -> do not change long name
+                if band != RAW_CLOUDS:
+                    cloud.attrs["long_name"] = band_name
+
+                band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
 
