@@ -76,9 +76,9 @@ class S2TheiaProduct(OpticalProduct):
         """
         Set product default resolution (in meters)
         """
-        # S2: use 20m resolution, even if we have 60m and 10m resolution
+        # S2: use 10m resolution, even if we have 60m and 20m resolution
         # In the future maybe set one resolution per band ?
-        return 20.0
+        return 10.0
 
     def _get_tile_name(self) -> str:
         """
@@ -91,9 +91,8 @@ class S2TheiaProduct(OpticalProduct):
         root, _ = self.read_mtd()
 
         # Open identifier
-        try:
-            tile = root.findtext(".//GEOGRAPHICAL_ZONE")
-        except TypeError:
+        tile = root.findtext(".//GEOGRAPHICAL_ZONE")
+        if not tile:
             raise InvalidProductError("GEOGRAPHICAL_ZONE not found in metadata!")
 
         return tile
@@ -163,7 +162,7 @@ class S2TheiaProduct(OpticalProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -186,9 +185,8 @@ class S2TheiaProduct(OpticalProduct):
             root, _ = self.read_mtd()
 
             # Open identifier
-            try:
-                acq_date = root.findtext(".//ACQUISITION_DATE")
-            except TypeError:
+            acq_date = root.findtext(".//ACQUISITION_DATE")
+            if not acq_date:
                 raise InvalidProductError("ACQUISITION_DATE not found in metadata!")
 
             # Convert to datetime
@@ -208,17 +206,13 @@ class S2TheiaProduct(OpticalProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
-            # Get MTD XML file
-            root, _ = self.read_mtd()
+        # Get MTD XML file
+        root, _ = self.read_mtd()
 
-            # Open identifier
-            try:
-                name = files.get_filename(root.findtext(".//IDENTIFIER"))
-            except TypeError:
-                raise InvalidProductError("IDENTIFIER not found in metadata!")
-        else:
-            name = self.name
+        # Open identifier
+        name = files.get_filename(root.findtext(".//IDENTIFIER"))
+        if not name:
+            raise InvalidProductError("IDENTIFIER not found in metadata!")
 
         return name
 
@@ -259,7 +253,7 @@ class S2TheiaProduct(OpticalProduct):
                 try:
                     if self.is_archived:
                         band_paths[band] = files.get_archived_rio_path(
-                            self.path, f".*FRE_B{self.band_names[band]}\.tif"
+                            self.path, rf".*FRE_B{self.band_names[band]}\.tif"
                         )
                     else:
                         band_paths[band] = files.get_file_in_dir(
@@ -316,8 +310,6 @@ class S2TheiaProduct(OpticalProduct):
 
         return band_xda
 
-    # pylint: disable=R0913
-    # R0913: Too many arguments (6/5) (too-many-arguments)
     def _manage_invalid_pixels(
         self, band_arr: XDS_TYPE, band: obn, **kwargs
     ) -> XDS_TYPE:
@@ -334,14 +326,11 @@ class S2TheiaProduct(OpticalProduct):
         Returns:
             XDS_TYPE: Cleaned band array
         """
-        nodata_true = 1
-        nodata_false = 0
-
         # -- Manage nodata from Theia band array
         # Theia nodata is already processed
         theia_nodata = -1.0
         no_data_mask = np.where(
-            band_arr.data == theia_nodata, nodata_true, nodata_false
+            band_arr.data == theia_nodata, self._mask_true, self._mask_false
         ).astype(np.uint8)
 
         # Open NODATA pixels mask
@@ -369,22 +358,44 @@ class S2TheiaProduct(OpticalProduct):
         # -- Merge masks
         return self._set_nodata_mask(band_arr, mask)
 
+    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
+        """
+        Manage only nodata pixels
+
+        Args:
+            band_arr (XDS_TYPE): Band array
+            band (obn): Band name as an OpticalBandNames
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            XDS_TYPE: Cleaned band array
+        """
+        # -- Manage nodata from Theia band array
+        # Theia nodata is already processed
+        theia_nodata = -1.0
+        no_data_mask = np.where(
+            band_arr.data == theia_nodata, self._mask_true, self._mask_false
+        ).astype(np.uint8)
+
+        # -- Merge masks
+        return self._set_nodata_mask(band_arr, no_data_mask)
+
     def get_mask_path(self, mask_id: str, res_id: str) -> Union[CloudPath, Path]:
         """
-        Get mask path from its id and file_id (`R1` for 10m resolution, `R2` for 20m resolution)
+        Get mask path from its id and file_id (:code:`R1` for 10m resolution, :code:`R2` for 20m resolution)
 
         Accepted mask IDs:
 
-        - `DFP`: Defective pixels (do not always exist ! Will raise `InvalidProductError` if not)
-        - `EDG`: Nodata pixels mask
-        - `SAT`: Saturated pixels mask
-        - `MG2`: Geophysical mask (classification)
-        - `IAB`: Mask where water vapor and TOA pixels have been interpolated
-        - `CLM`: Cloud mask
+        - :code:`DFP`: Defective pixels (do not always exist ! Will raise :code:`InvalidProductError` if not)
+        - :code:`EDG`: Nodata pixels mask
+        - :code:`SAT`: Saturated pixels mask
+        - :code:`MG2`: Geophysical mask (classification)
+        - :code:`IAB`: Mask where water vapor and TOA pixels have been interpolated
+        - :code:`CLM`: Cloud mask
 
         Args:
             mask_id (str): Mask ID
-            res_id (str): Resolution ID (`R1` or `R2`)
+            res_id (str): Resolution ID (:code:`R1` or :code:`R2`)
 
         Returns:
             Union[CloudPath, Path]: Mask path
@@ -422,18 +433,18 @@ class S2TheiaProduct(OpticalProduct):
         - Opens the nodata binary mask
         - Opens the other masks as is
 
-        Do not open cloud mask with this function. Use `load` instead.
+        Do not open cloud mask with this function. Use :code:`load` instead.
 
         See `here <https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/>`_ for more
         information.
 
         Accepted mask IDs:
 
-        - `DFP`: Defective pixels
-        - `EDG`: Nodata pixels mask
-        - `SAT`: Saturated pixels mask
-        - `MG2`: Geophysical mask (classification)
-        - `IAB`: Mask where water vapor and TOA pixels have been interpolated
+        - :code:`DFP`: Defective pixels
+        - :code:`EDG`: Nodata pixels mask
+        - :code:`SAT`: Saturated pixels mask
+        - :code:`MG2`: Geophysical mask (classification)
+        - :code:`IAB`: Mask where water vapor and TOA pixels have been interpolated
 
         .. code-block:: python
 
@@ -446,7 +457,7 @@ class S2TheiaProduct(OpticalProduct):
 
         Args:
             mask_id: Mask ID
-            band (Union[obn, str]): Band name as an OpticalBandNames or resolution ID: [`R1`, `R2`]
+            band (Union[obn, str]): Band name as an OpticalBandNames or resolution ID: ['R1', 'R2']
             resolution (float): Band resolution in meters
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
 
@@ -518,7 +529,7 @@ class S2TheiaProduct(OpticalProduct):
         # Get band paths
         if resolution is None and size is not None:
             resolution = self._resolution_from_size(size)
-        band_paths = self.get_band_paths(bands, resolution=resolution)
+        band_paths = self.get_band_paths(bands, resolution=resolution, **kwargs)
 
         # Open bands and get array (resampled if needed)
         band_arrays = self._open_bands(
@@ -583,7 +594,7 @@ class S2TheiaProduct(OpticalProduct):
             (etree._Element, dict): Metadata XML root and its namespaces
         """
         mtd_from_path = "MTD_ALL.xml"
-        mtd_archived = "MTD_ALL\.xml"
+        mtd_archived = r"MTD_ALL\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
@@ -626,9 +637,17 @@ class S2TheiaProduct(OpticalProduct):
         """
         band_dict = {}
 
+        if resolution:
+            res_file = resolution
+        else:
+            if size:
+                res_file = self._resolution_from_size(size)[0]
+            else:
+                res_file = self.resolution
+
         if bands:
             # Open 20m cloud file if resolution >= 20m
-            res_id = "R2" if resolution >= 20 else "R1"
+            res_id = "R2" if res_file >= 20 else "R1"
 
             cloud_path = self.get_mask_path("CLM", res_id)
             clouds_mask = utils.read(
@@ -670,8 +689,11 @@ class S2TheiaProduct(OpticalProduct):
 
                 # Rename
                 band_name = to_str(band)[0]
-                cloud.attrs["long_name"] = band_name
-                band_dict[band] = cloud.rename(band_name)
+
+                # Multi bands -> do not change long name
+                if band != RAW_CLOUDS:
+                    cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name).astype(np.float32)
 
         return band_dict
 
