@@ -88,13 +88,8 @@ class S3OlciProduct(S3Product):
 
         """
         https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-slstr/level-1/observation-mode-desc
-        Note that the name of each netCDF file provides information about it's content.
-        The suffix of each filename is associated with the selected grid:
-            "an" and "ao" refer to the 500 m grid, stripe A, respectively for nadir view (n) and oblique view (o)
-            "bn" and "bo" refer to the 500 m grid, stripe B
-            "in" and "io" refer to the 1 km grid
-            "fn" and "fo" refer to the F1 channel 1 km grid
-            "tx/n/o" refer to the tie-point grid for agnostic/nadir and oblique view
+
+        Note that the name of each netCDF file provides information about its content.
         """
         super().__init__(
             product_path, archive_path, output_path, remove_tmp
@@ -259,7 +254,9 @@ class S3OlciProduct(S3Product):
         """
         band_str = band if isinstance(band, str) else band.name
 
-        path = self._get_preprocessed_band_path(band, resolution=resolution)
+        path = self._get_preprocessed_band_path(
+            band, resolution=resolution, writable=False
+        )
 
         if not path.is_file():
             path = self._get_preprocessed_band_path(
@@ -419,8 +416,6 @@ class S3OlciProduct(S3Product):
 
         return e0
 
-    # pylint: disable=R0913
-    # R0913: Too many arguments (6/5) (too-many-arguments)
     def _manage_invalid_pixels(
         self, band_arr: XDS_TYPE, band: obn, **kwargs
     ) -> XDS_TYPE:
@@ -529,7 +524,6 @@ class S3OlciProduct(S3Product):
         # Combine masks
         mask = no_data | invalid | sat
 
-        # DO not set 0 to epsilons as they are a part of the
         return self._set_nodata_mask(band_arr, mask)
 
     def _has_cloud_band(self, band: BandNames) -> bool:
