@@ -28,7 +28,7 @@ import tempfile
 from abc import abstractmethod
 from enum import unique
 from pathlib import Path
-from typing import Any, Callable, Union
+from typing import Callable, Union
 
 import geopandas as gpd
 import numpy as np
@@ -52,7 +52,8 @@ from eoreader.bands import *
 from eoreader.bands import index
 from eoreader.bands.bands import BandNames
 from eoreader.env_vars import CI_EOREADER_BAND_FOLDER, DEM_PATH
-from eoreader.exceptions import InvalidProductError
+from eoreader.exceptions import InvalidProductError, InvalidTypeError
+from eoreader.keywords import DEM_KW, HILLSHADE_KW, SLOPE_KW
 from eoreader.reader import Platform, Reader
 from eoreader.utils import EOREADER_NAME
 
@@ -82,9 +83,10 @@ class Product:
         archive_path: Union[str, CloudPath, Path] = None,
         output_path: Union[str, CloudPath, Path] = None,
         remove_tmp: bool = False,
+        **kwargs,
     ) -> None:
         self.needs_extraction = True
-        """Does this products needs to be extracted to be processed ? (`True` by default)."""
+        """Does this products needs to be extracted to be processed ? (:code:`True` by default)."""
 
         self.path = AnyPath(product_path)
         """Usable path to the product, either extracted or archived path, according to the satellite."""
@@ -130,7 +132,10 @@ class Product:
         """Product type, satellite-related field, such as L1C or L2A for Sentinel-2 data."""
 
         self.band_names = None
-        """Band mapping between band wrapping names such as `GREEN` and band real number such as `03` for Sentinel-2."""
+        """
+        Band mapping between band wrapping names such as
+        :code:`GREEN` and band real number such as :code:`03` for Sentinel-2.
+        """
 
         self.is_reference = False
         """If the product is a reference, used for algorithms that need pre and post data, such as fire detection."""
@@ -141,7 +146,7 @@ class Product:
          A list because of multiple ref in case of non-stackable products (S3, S1...)"""
 
         self.nodata = -9999
-        """ Product nodata, set to -999 by default """
+        """ Product nodata, set to -9999 by default """
 
         # Mask values
         self._mask_true = 1
@@ -161,12 +166,12 @@ class Product:
         self.condensed_name = None
         """
         Condensed name, the filename with only useful data to keep the name unique
-        (ie. `20191215T110441_S2_30TXP_L2A_122756`).
+        (ie. :code:`20191215T110441_S2_30TXP_L2A_122756`).
         Used to shorten names and paths.
         """
 
         self.sat_id = None
-        """Satellite ID, i.e. `S2` for Sentinel-2"""
+        """Satellite ID, i.e. :code:`S2` for :code:`Sentinel-2`"""
 
         # Manage output
         if output_path:
@@ -177,7 +182,7 @@ class Product:
             self._output = AnyPath(self._tmp_output.name)
 
         # Pre initialization
-        self._pre_init()
+        self._pre_init(**kwargs)
 
         # Only compute data if OK (for now OK is extracted if needed)
         if self.is_archived and self.needs_extraction:
@@ -196,7 +201,7 @@ class Product:
             self.sat_id = self.platform.name
 
             # Post initialization
-            self._post_init()
+            self._post_init(**kwargs)
 
             # Set product type, needs to be done after the post-initialization
             self._set_product_type()
@@ -223,12 +228,12 @@ class Product:
             files.remove(self._tmp_process)
 
     @abstractmethod
-    def _pre_init(self) -> None:
+    def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def _post_init(self) -> None:
@@ -236,7 +241,7 @@ class Product:
         Function used to post_init the products
         (setting sensor type, band names and so on)
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @cached_property
     def footprint(self) -> gpd.GeoDataFrame:
@@ -255,11 +260,7 @@ class Product:
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
         """
-        def_band = self.get_default_band()
-        default_xda = self.load(def_band)[
-            def_band
-        ]  # Forced to load as the nodata may not be positioned by default
-        return rasters.get_footprint(default_xda).to_crs(self.crs)
+        raise NotImplementedError
 
     @cached_property
     @abstractmethod
@@ -279,7 +280,7 @@ class Product:
         Returns:
             gpd.GeoDataFrame: Footprint in UTM
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @cached_property
     @abstractmethod
@@ -298,7 +299,7 @@ class Product:
         Returns:
             crs.CRS: CRS object
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def _get_band_folder(self, writable: bool = False) -> Union[CloudPath, Path]:
         """
@@ -309,13 +310,13 @@ class Product:
         """
         band_folder = self._tmp_process
 
-        # Manage CI SNAP band
-        ci_band_folder = os.environ.get(CI_EOREADER_BAND_FOLDER)
-        if ci_band_folder:
-            ci_band_folder = AnyPath(ci_band_folder)
-            if ci_band_folder.is_dir():
-                # If we need a writable directory, check it
-                if (writable and files.is_writable(ci_band_folder)) or not writable:
+        # Manage CI bands (when we do not write anything, read only)
+        if not writable:
+            ci_band_folder = os.environ.get(CI_EOREADER_BAND_FOLDER)
+            if ci_band_folder:
+                ci_band_folder = AnyPath(ci_band_folder)
+                if ci_band_folder.is_dir():
+                    # If we need a writable directory, check it
                     band_folder = ci_band_folder
 
         return band_folder
@@ -325,14 +326,14 @@ class Product:
         """
         Set product default resolution (in meters)
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def _set_product_type(self) -> None:
         """
         Set product type
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @classmethod
     def _get_platform(cls) -> Platform:
@@ -348,7 +349,7 @@ class Product:
         Returns:
             str: True name of the product (from metadata)
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def _get_condensed_name(self) -> str:
@@ -358,7 +359,7 @@ class Product:
         Returns:
             str: Condensed name
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def _get_split_name(self) -> list:
         """
@@ -372,7 +373,7 @@ class Product:
     @abstractmethod
     def get_datetime(self, as_datetime: bool = False) -> Union[str, dt.datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -390,7 +391,7 @@ class Product:
         Returns:
              Union[str, datetime.datetime]: Its acquisition datetime
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def get_date(self, as_date: bool = False) -> Union[str, dt.date]:
         """
@@ -424,7 +425,7 @@ class Product:
         """
         Get default band path (among the existing ones).
 
-        Usually `GREEN` band for optical data and the first existing one between `VV` and `HH` for SAR data.
+        Usually :code:`GREEN` band for optical data and the first existing one between :code:`VV` and :code:`HH` for SAR data.
 
         .. code-block:: python
 
@@ -440,13 +441,13 @@ class Product:
         Returns:
             Union[CloudPath, Path]: Default band path
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def get_default_band(self) -> BandNames:
         """
         Get default band:
-        Usually `GREEN` band for optical data and the first existing one between `VV` and `HH` for SAR data.
+        Usually :code:`GREEN` band for optical data and the first existing one between :code:`VV` and :code:`HH` for SAR data.
 
         .. code-block:: python
 
@@ -460,7 +461,7 @@ class Product:
         Returns:
             str: Default band
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def get_existing_bands(self) -> list:
@@ -490,7 +491,7 @@ class Product:
         Returns:
             list: List of existing bands in the products
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def get_existing_band_paths(self) -> dict:
@@ -512,7 +513,7 @@ class Product:
         Returns:
             dict: Dictionary containing the path of each queried band
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def get_band_paths(
@@ -541,18 +542,17 @@ class Product:
         Returns:
             dict: Dictionary containing the path of each queried band
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
-    def _read_mtd(self) -> Any:
+    def _read_mtd(self) -> (etree._Element, dict):
         """
-        Read metadata and outputs the metadata XML root and its namespaces as a dict most of the time,
-        except from L8-collection 1 data which outputs a `pandas.DataFrame`
+        Read metadata and outputs the metadata XML root and its namespaces as a dict
 
         Returns:
-            Any: Metadata XML root and its namespace or pd.DataFrame
+            (etree._Element, dict): Metadata XML root and its namespace
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def _read_mtd_xml(
         self, mtd_from_path: str, mtd_archived: str = None
@@ -647,10 +647,9 @@ class Product:
 
         return root
 
-    def read_mtd(self) -> Any:
+    def read_mtd(self) -> (etree._Element, dict):
         """
-        Read metadata and outputs the metadata XML root and its namespaces as a dict most of the time,
-        except from L8-collection 1 data which outputs a `pandas.DataFrame`
+        Read metadata and outputs the metadata XML root and its namespaces as a dict.
 
         .. code-block:: python
 
@@ -661,7 +660,7 @@ class Product:
             (<Element product at 0x1832895d788>, '')
 
         Returns:
-            Any: Metadata XML root and its namespace or pd.DataFrame
+            (etree._Element, dict): Metadata XML root and its namespace
         """
         return self._read_mtd()
 
@@ -691,7 +690,7 @@ class Product:
             XDS_TYPE: Band xarray
 
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     @abstractmethod
     def _load_bands(
@@ -708,12 +707,11 @@ class Product:
             bands (list): List of the wanted bands
             resolution (int): Band resolution in meters
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-            kwargs: Additional arguments
             kwargs: Other arguments used to load bands
         Returns:
             dict: Dictionary {band_name, band_xarray}
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def _load_dem(
         self,
@@ -740,15 +738,22 @@ class Product:
                 assert is_dem(band)
                 if band == DEM:
                     path = self._warp_dem(
-                        dem_path, resolution=resolution, size=size, **kwargs
+                        kwargs.get(DEM_KW, dem_path),
+                        resolution=resolution,
+                        size=size,
+                        **kwargs,
                     )
                 elif band == SLOPE:
                     path = self._compute_slope(
-                        dem_path, resolution=resolution, size=size
+                        kwargs.get(SLOPE_KW, dem_path),
+                        resolution=resolution,
+                        size=size,
                     )
                 elif band == HILLSHADE:
                     path = self._compute_hillshade(
-                        dem_path, resolution=resolution, size=size
+                        kwargs.get(HILLSHADE_KW, dem_path),
+                        resolution=resolution,
+                        size=size,
                     )
                 else:
                     raise InvalidTypeError(f"Unknown DEM band: {band}")
@@ -833,12 +838,19 @@ class Product:
         Returns:
             dict: {band_name, band xarray}
         """
-        if not resolution and not size:
-            resolution = self.resolution
 
         # Check if all bands are valid
-        if not isinstance(bands, list):
-            bands = [bands]
+        bands = to_band(bands)
+
+        for band in bands:
+            try:
+                band_name = band.value
+            except AttributeError:
+                band_name = band
+            assert self.has_band(band), f"{self.name} has not a {band_name} band."
+
+        if not resolution and not size:
+            resolution = self.resolution
 
         # Load bands (only once ! and convert the bands to be loaded to correct format)
         unique_bands = list(set(to_band(bands)))
@@ -880,7 +892,7 @@ class Product:
         Returns:
             Dictionary {band_name, band_xarray}
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def has_band(self, band: Union[BandNames, Callable]) -> bool:
         """
@@ -911,7 +923,7 @@ class Product:
             True
 
         Args:
-            band (Union[BandNames, Callable]): Optical or SAR band
+            band (Union[BandNames, Callable]): EOReader band (optical, SAR, clouds, DEM)
 
         Returns:
             bool: True if the products has the specified band
@@ -941,10 +953,10 @@ class Product:
         - DEM band
         - cloud band
 
-        See `has_bands` for a code example.
+        See :code:`has_bands` for a code example.
 
         Args:
-            band (Union[list, BandNames, Callable]): List (or unique value) of Optical or SAR bands
+            bands (Union[list, BandNames, Callable]): EOReader bands (optical, SAR, clouds, DEM)
 
         Returns:
             bool: True if the products has the specified band
@@ -968,7 +980,7 @@ class Product:
             >>> prod.has_cloud_band(CLOUDS)
             True
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def _has_index(self, idx: Callable) -> bool:
         """
@@ -1133,7 +1145,7 @@ class Product:
         Returns:
             str: DEM path (as a VRT)
         """
-        dem_name = f"{self.condensed_name}_DEM.tif"
+        dem_name = f"{self.condensed_name}_DEM_{files.get_filename(dem_path)}.tif"
         warped_dem_path = self._get_band_folder().joinpath(dem_name)
         if warped_dem_path.is_file():
             LOGGER.debug(
@@ -1145,7 +1157,7 @@ class Product:
 
             # Allow S3 HTTP Urls only on Linux because rasterio bugs on Windows
             if validators.url(dem_path) and platform.system() == "Windows":
-                raise Exception(
+                raise OSError(
                     f"URLs to DEM like {dem_path} are not supported on Windows! Use Docker or Linux instead"
                 )
 
@@ -1248,7 +1260,7 @@ class Product:
             str: Hillshade mask path
 
         """
-        raise NotImplementedError("This method should be implemented by a child class")
+        raise NotImplementedError
 
     def _compute_slope(
         self,
@@ -1274,7 +1286,7 @@ class Product:
         warped_dem_path = self._warp_dem(dem_path, resolution, size, resampling)
 
         # Get slope path
-        slope_name = f"{self.condensed_name}_SLOPE.tif"
+        slope_name = f"{self.condensed_name}_SLOPE_{files.get_filename(dem_path)}.tif"
         slope_path = self._get_band_folder().joinpath(slope_name)
         if slope_path.is_file():
             LOGGER.debug(
@@ -1397,7 +1409,7 @@ class Product:
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
             stack_path (Union[str, CloudPath, Path]): Stack path
             save_as_int (bool): Convert stack to uint16 to save disk space (and therefore multiply the values by 10.000)
-            **kwargs: Other arguments passed to `load` or `rioxarray.to_raster()` (such as `compress`)
+            **kwargs: Other arguments passed to :code:`load` or :code:`rioxarray.to_raster()` (such as :code:`compress`)
 
         Returns:
             xr.DataArray: Stack as a DataArray
@@ -1437,7 +1449,7 @@ class Product:
                 # - Satellite bands
                 # - index
                 for b_id, band in enumerate(bands):
-                    if is_band(band) or is_index(band):
+                    if is_sat_band(band) or is_index(band):
                         stack[b_id, ...] = stack[b_id, ...] * 10000
 
                 # CONVERSION
@@ -1481,31 +1493,47 @@ class Product:
             long_name (str): Array name (as a str or a list)
         """
         if isinstance(long_name, list):
-            name = "_".join(long_name)
+            name = " ".join(long_name)
         else:
             name = long_name
 
         renamed_xarr = xarr.rename(name)
-        renamed_xarr.attrs["long_name"] = long_name
+        renamed_xarr.attrs["long_name"] = name
         renamed_xarr.attrs["sensor"] = self._get_platform().value
         renamed_xarr.attrs["sensor_id"] = self.sat_id
         renamed_xarr.attrs["product_path"] = str(self.path)  # Convert to string
         renamed_xarr.attrs["product_name"] = self.name
         renamed_xarr.attrs["product_filename"] = self.filename
-        renamed_xarr.attrs["product_type"] = self.product_type.value
+        renamed_xarr.attrs["product_type"] = (
+            self.product_type
+            if isinstance(self.product_type, str)
+            else self.product_type.value
+        )
         renamed_xarr.attrs["acquisition_date"] = self.get_datetime(as_datetime=False)
         renamed_xarr.attrs["condensed_name"] = self.condensed_name
 
         return renamed_xarr
 
     @staticmethod
-    def _check_dem_path() -> None:
-        """ Check if DEM is set and exists"""
+    def _check_dem_path(bands: list, **kwargs) -> None:
+        """
+        Check if DEM is set and exists if DEM bands are asked.
+
+        Args:
+            bands (list): List of the wanted bands
+            kwargs: Other arguments used to load bands
+        """
         if DEM_PATH not in os.environ:
-            raise ValueError(
-                f"Dem path not set, unable to compute DEM bands! "
-                f"Please set the environment variable {DEM_PATH}."
-            )
+            if (
+                (DEM in bands and DEM_KW not in kwargs)
+                or (SLOPE in bands and SLOPE_KW not in kwargs)
+                or (HILLSHADE in bands and HILLSHADE_KW not in kwargs)
+            ):
+
+                raise ValueError(
+                    f"DEM path not set, unable to compute DEM bands! "
+                    f"Please set the environment variable {DEM_PATH} or a DEM keyword."
+                )
         else:
             dem_path = os.environ.get(DEM_PATH)
             # URLs and file paths are required
@@ -1521,7 +1549,7 @@ class Product:
     def default_transform(self, **kwargs) -> (Affine, int, int, CRS):
         """
         Returns default transform data of the default band (UTM),
-        as the `rasterio.warp.calculate_default_transform` does:
+        as the :code:`rasterio.warp.calculate_default_transform` does:
         - transform
         - width
         - height
