@@ -27,7 +27,8 @@ from typing import Union
 import geopandas as gpd
 import rasterio
 from lxml import etree
-from sertit import files, vectors
+from rasterio import crs
+from sertit import files, rasters, vectors
 from sertit.misc import ListEnum
 
 from eoreader import cache, cached_property
@@ -156,59 +157,47 @@ class TsxProduct(SarProduct):
             )
         except (InvalidProductError, TypeError):
             raise InvalidProductError(
-                "imageDataInfo or rowSpacing not found in metadata!"
+                "acquisitionInfo or polarisationMode not found in metadata!"
             )
 
         def_res = None
-        # For complex data, set regular ground range resolution provided by the constructor
-        # Missing spotlight and ship detection because the values are contextual
-        if self.product_type == TsxProductType.SSC:
-            if self.sensor_mode == TsxSensorMode.HS:
-                if polarization == TsxPolarization.S:
-                    def_res = 0.75
-                elif polarization == TsxPolarization.D:
-                    def_res = 1.5
-            elif self.sensor_mode == TsxSensorMode.SL:
-                if polarization == TsxPolarization.S:
-                    def_res = 1.5
-                elif polarization == TsxPolarization.D:
-                    def_res = 1.5
-            elif self.sensor_mode == TsxSensorMode.ST:
-                if polarization == TsxPolarization.S:
-                    def_res = 0.4
-            elif self.sensor_mode == TsxSensorMode.SM:
-                if polarization == TsxPolarization.S:
-                    def_res = 1.5
-                elif polarization == TsxPolarization.D:
-                    def_res = 3.0
-            elif self.sensor_mode == TsxSensorMode.SC:
-                # Read metadata
-                try:
-                    root, _ = self.read_mtd()
-                    acq_info = root.find(".//acquisitionInfo")
-                    nof_beams = int(acq_info.findtext(".//numberOfBeams"))
-                except (InvalidProductError, TypeError):
-                    raise InvalidProductError(
-                        "imageDataInfo or rowSpacing not found in metadata!"
-                    )
-                # Four beams
-                if nof_beams == 4:
-                    def_res = 8.25
-
-                elif nof_beams == 6:
-                    # Six beams
-                    def_res = 15.0
-
-        if not def_res:
+        if self.sensor_mode == TsxSensorMode.HS:
+            if polarization == TsxPolarization.S:
+                def_res = 1.1
+            elif polarization == TsxPolarization.D:
+                def_res = 2.2
+        elif self.sensor_mode == TsxSensorMode.SL:
+            if polarization == TsxPolarization.S:
+                def_res = 1.7
+            elif polarization == TsxPolarization.D:
+                def_res = 3.4
+        elif self.sensor_mode == TsxSensorMode.ST:
+            if polarization == TsxPolarization.S:
+                def_res = 0.24
+        elif self.sensor_mode == TsxSensorMode.SM:
+            if polarization == TsxPolarization.S:
+                def_res = 3.3
+            elif polarization == TsxPolarization.D:
+                def_res = 6.6
+        elif self.sensor_mode == TsxSensorMode.SC:
             # Read metadata
             try:
                 root, _ = self.read_mtd()
-                img_data = root.find(".//imageDataInfo")
-                def_res = float(img_data.findtext(".//rowSpacing"))  # Square pixels
+                acq_info = root.find(".//acquisitionInfo")
+                nof_beams = int(acq_info.findtext(".//numberOfBeams"))
             except (InvalidProductError, TypeError):
                 raise InvalidProductError(
                     "imageDataInfo or rowSpacing not found in metadata!"
                 )
+            # Four beams
+            if nof_beams == 4:
+                def_res = 18.5
+
+            elif nof_beams == 6:
+                # Six beams
+                def_res = 40.0
+        else:
+            raise InvalidProductError(f"Unknown sensor mode: {self.sensor_mode}")
 
         return def_res
 
@@ -247,6 +236,51 @@ class TsxProduct(SarProduct):
         # Post init done by the super class
         super()._post_init()
 
+    @cached_property
+    def extent(self) -> gpd.GeoDataFrame:
+        """
+        Get UTM extent of the tile
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.utm_extent()
+                                   Name  ...                                           geometry
+            0  Sentinel-1 Image Overlay  ...  POLYGON ((817914.501 4684349.823, 555708.624 4...
+            [1 rows x 12 columns]
+
+        Returns:
+            gpd.GeoDataFrame: Footprint in UTM
+        """
+        if self.product_type == TsxProductType.EEC:
+            return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs)
+        else:
+            return super().extent
+
+    @cached_property
+    def crs(self) -> crs.CRS:
+        """
+        Get UTM projection
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.utm_crs()
+            CRS.from_epsg(32630)
+
+        Returns:
+            crs.CRS: CRS object
+        """
+        if self.product_type == TsxProductType.EEC:
+            with rasterio.open(self.get_default_band_path()) as ds:
+                return ds.crs
+        else:
+            return super().crs
+
     @cached_property
     def wgs84_extent(self) -> gpd.GeoDataFrame:
         """
@@ -284,14 +318,17 @@ class TsxProduct(SarProduct):
         root, _ = self.read_mtd()
 
         # Open identifier
-        try:
-            prod_type = root.findtext(".//productVariant")
-        except TypeError:
-            raise InvalidProductError("mode not found in metadata!")
+        prod_type = root.findtext(".//productVariant")
+        if not prod_type:
+            raise InvalidProductError("productVariant not found in metadata!")
 
         self.product_type = TsxProductType.from_value(prod_type)
 
-        if self.product_type == TsxProductType.MGD:
+        if self.product_type in [
+            TsxProductType.MGD,
+            TsxProductType.GEC,
+            TsxProductType.EEC,
+        ]:
             self.sar_prod_type = SarProductType.GDRG
         elif self.product_type == TsxProductType.SSC:
             self.sar_prod_type = SarProductType.CPLX
@@ -299,9 +336,9 @@ class TsxProduct(SarProduct):
             raise NotImplementedError(
                 f"{self.product_type.value} product type is not available for {self.name}"
             )
-        if self.product_type != TsxProductType.MGD:
+        if self.product_type == TsxProductType.GEC:
             LOGGER.warning(
-                "Other products type than MGD has not been tested for %s data. "
+                "GEC (Geocoded Ellipsoid Corrected) products type has never been tested for %s data. "
                 "Use it at your own risks !",
                 self.platform.value,
             )
@@ -314,9 +351,8 @@ class TsxProduct(SarProduct):
         root, _ = self.read_mtd()
 
         # Open identifier
-        try:
-            imaging_mode = root.findtext(".//imagingMode")
-        except TypeError:
+        imaging_mode = root.findtext(".//imagingMode")
+        if not imaging_mode:
             raise InvalidProductError("imagingMode not found in metadata!")
 
         # Get sensor mode
@@ -327,7 +363,7 @@ class TsxProduct(SarProduct):
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
-        Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
+        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
 
         .. code-block:: python
 
@@ -350,9 +386,8 @@ class TsxProduct(SarProduct):
             root, _ = self.read_mtd()
 
             # Open identifier
-            try:
-                acq_date = root.findtext(".//start/timeUTC")
-            except TypeError:
+            acq_date = root.findtext(".//start/timeUTC")
+            if not acq_date:
                 raise InvalidProductError("start/timeUTC not found in metadata!")
 
             # Convert to datetime
@@ -372,19 +407,16 @@ class TsxProduct(SarProduct):
         Returns:
             str: True name of the product (from metadata)
         """
-        if self.name is None:
-            # Get MTD XML file
-            root, _ = self.read_mtd()
+        # Get MTD XML file
+        root, _ = self.read_mtd()
 
-            # Open identifier
-            try:
-                name = files.get_filename(
-                    root.find(".//generalHeader").attrib.get("fileName")
-                )
-            except TypeError:
-                raise InvalidProductError("ProductName not found in metadata!")
-        else:
-            name = self.name
+        # Open identifier
+        try:
+            name = files.get_filename(
+                root.find(".//generalHeader").attrib.get("fileName")
+            )
+        except TypeError:
+            raise InvalidProductError("ProductName not found in metadata!")
 
         return name
 
@@ -404,7 +436,7 @@ class TsxProduct(SarProduct):
         Returns:
             (etree._Element, dict): Metadata XML root and its namespaces
         """
-        # Cloud paths
+        # Cloud-stored paths
         try:
             mtd_from_path = "SAR*SAR*xml"
 
